const env = "__ENV__"

import wepy from "wepy";
import { md5 } from "md5";

export const config = {
    'api': (() => {
        let envMap = {
            'dev': 'https://test-wxapi-glance.duowan.com',//本地&测试
            'preview': 'https://wxapi-glance.duowan.com',		//预发布
            'production': 'https://wxapi-glance.duowan.com',	//线上
        }

        return envMap[env]
    })(),
    'apiPlus': (() => {
        let envMap = {
            'dev': 'https://test-glplus.duowan.com',	//本地&测试
            'preview': 'https://glplus.duowan.com',		//预发布
            'production': 'https://glplus.duowan.com',	//线上
        }
        return envMap[env]
    })(),
    'SHOP_ID': 17,
    'APP_ID': 1002
}

export const lib = {
    //获取任务列表
    getTaskList() {
        return new Promise((resolve, reject) => {
            wepy
                .request({
                    url: `${config.apiPlus}/task/list`,
                    data: {}
                }).then(({ data }) => {
                    if (data.code == 0) {
                        resolve(data.data)
                    } else {
                        resolve(false)
                    }
                })
        })
    },
    encodePwd(random, pwd) {
        var k1 = md5.sha1(random);
        var k2 = md5.sha1(k1);

        var v = md5.xor(md5.xor(pwd, k2), k1);
        return md5.base64encode(v);
    },
    //任务上报
    reportTask(task_id) { //glancePlayMinute:看视频;share:分享;daySign:每日签到
        let loginData = wx.getStorageSync('loginData')

        if (!task_id && !loginData) return

        let timeStamp = (new Date()).getTime()
        let data = {
            shop_id: config.SHOP_ID,
            task_id: task_id,
            target_id: loginData.uid,
            time: timeStamp
        }

        let paramData = `shop_id=${config.SHOP_ID}&task_id=${task_id}&target_id=${loginData.uid}&time=${timeStamp}`
        data["sign"] = this.encodePwd(loginData.token, md5.sha1(paramData));

        return new Promise((resolve, reject) => {
            wepy
                .request({
                    url: `${config.apiPlus}/task/report`,
                    data: data
                }).then(({ data }) => {
                    if (data.code == 0) {
                        resolve(true)
                    } else {
                        if (task_id == "daySign") wx.showToast({ title: data.msg || '' })

                        resolve(false)
                    }
                })
        })
    },
    //获取个人金币信息
    getGoldInfo() {
        return new Promise((resolve, reject) => {
            wepy.request({
                url: `${config.apiPlus}/user/info`,
                data: {}
            }).then(({ data }) => {
                if (data.code == 0) {
                    resolve(data.data)
                } else {
                    resolve(false)
                }
            })
        })
    },
    // 分享
    shareInfo(yyuid) {
        let loginData = wx.getStorageSync('loginData')
        if (!loginData) return false
        let otoken = loginData.token
        let ouid = loginData.uid
        let openid = loginData.openId;
        return new Promise((resolve, reject) => {
            wepy.request({
                url: `${config.apiPlus}/user/shareInfo`,
                data: {
                    ouid,
                    otoken,
                    yyuid,
                    openid
                }
            }).then(({ data }) => {
                if (data.code == 0) {
                    resolve(data.data)
                } else {
                    resolve(false)
                }
            })
        })
    },
    getShareImage(){
        let random = Math.floor(Math.random()*8)
            random = random>7 ? 7 : random
        let image = `https://pub.dwstatic.com/act/glancewx/share/cover${random}.jpg`
        
        return image
    }
}

export class TaskClient {
    constructor(x) {
        this.x = x
    }
    // 邀请好友
    invite() {
    }
    // 发评论
    comment() {

    }
    // 每日登录
    login() {

    }
    // 转发
    forward() {

    }
}


